from setuptools import setup

setup(name='gabi_distribution',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gabi_distribution'],
      author = 'Anukool Rathi',
      author_email = 'Anukool.rathi10@gmail.com',
      zip_safe=False)